# Via

<img src="/assets/logo.png" alt="via logo" style="height: 100px; width:100px;"/>

Road quality assessment from cycling / driving / bussing around, tools to analyse data collected from the android app https://github.com/RobertLucey/road-quality-aggregator

All uploaded data is public and no accounts required. Neat privacy to make it very difficult / impossible (depending on your settings and how many trips have been taken in the area) to find the route of an individual journey as well as its origin / destination
